@@ -1,4 +1,4 @@
-#![deny(warnings)]
+#![deny(clippy::all, clippy::pedantic, warnings)]
 
 mod cache;
 mod config;
@@ -60,7 +60,9 @@ const READ_LOCAL_CACHE_OPTION: &str = "read-local-cache";
 const WRITE_LOCAL_CACHE_OPTION: &str = "write-local-cache";
 const READ_REMOTE_CACHE_OPTION: &str = "read-remote-cache";
 const WRITE_REMOTE_CACHE_OPTION: &str = "write-remote-cache";
-const REPO_OPTION: &str = "repo";
+const DOCKER_CLI_OPTION: &str = "docker-cli";
+const DOCKER_REPO_OPTION: &str = "docker-repo";
+const DEPRECATED_REPO_OPTION: &str = "repo";
 const LIST_OPTION: &str = "list";
 const SHELL_OPTION: &str = "shell";
 const TASKS_OPTION: &str = "tasks";
@@ -106,6 +108,7 @@ fn set_up_logging() {
 
 // Set up the signal handlers.
 fn set_up_signal_handlers(
+    docker_cli: String,
     interrupted: Arc<AtomicBool>,
     active_containers: Arc<Mutex<HashSet<String>>>,
 ) -> Result<(), Failure> {
@@ -119,7 +122,7 @@ fn set_up_signal_handlers(
         if interrupted.swap(true, Ordering::SeqCst) {
             // Stop any active containers. The `unwrap` will only fail if a panic already occurred.
             for container in &*active_containers.lock().unwrap() {
-                if let Err(e) = docker::stop_container(&container, &interrupted) {
+                if let Err(e) = docker::stop_container(&docker_cli, container, &interrupted) {
                     error!("{}", e);
                 }
             }
@@ -149,6 +152,7 @@ fn parse_bool(s: &str) -> Result<bool, Failure> {
 #[allow(clippy::struct_excessive_bools)]
 pub struct Settings {
     toastfile_path: PathBuf,
+    docker_cli: String,
     docker_repo: String,
     read_local_cache: bool,
     write_local_cache: bool,
@@ -210,12 +214,24 @@ fn settings() -> Result<Settings, Failure> {
                 .help("Sets whether remote cache writing is enabled"),
         )
         .arg(
-            Arg::with_name(REPO_OPTION)
+            Arg::with_name(DOCKER_REPO_OPTION)
                 .value_name("REPO")
                 .short("r")
-                .long(REPO_OPTION)
+                .long(DOCKER_REPO_OPTION)
                 .help("Sets the Docker repository"),
         )
+        .arg(
+            Arg::with_name(DEPRECATED_REPO_OPTION)
+                .value_name("REPO")
+                .long(DEPRECATED_REPO_OPTION)
+                .help("Deprecated, use --docker-repo instead"),
+        )
+        .arg(
+            Arg::with_name(DOCKER_CLI_OPTION)
+                .value_name("CLI")
+                .long(DOCKER_CLI_OPTION)
+                .help("Sets the Docker CLI binary"),
+        )
         .arg(
             Arg::with_name(LIST_OPTION)
                 .short("l")
@@ -323,10 +339,17 @@ fn settings() -> Result<Settings, Failure> {
 
     // Read the Docker repo.
     let docker_repo = matches
-        .value_of(REPO_OPTION)
+        .value_of(DOCKER_REPO_OPTION)
+        .or_else(|| matches.value_of(DEPRECATED_REPO_OPTION))
         .unwrap_or(&config.docker_repo)
         .to_owned();
 
+    // Read the Docker CLI.
+    let docker_cli = matches
+        .value_of(DOCKER_CLI_OPTION)
+        .unwrap_or(&config.docker_cli)
+        .to_owned();
+
     // Read the list switch.
     let list = matches.is_present(LIST_OPTION);
 
@@ -351,6 +374,7 @@ fn settings() -> Result<Settings, Failure> {
 
     Ok(Settings {
         toastfile_path,
+        docker_cli,
         docker_repo,
         read_local_cache,
         write_local_cache,
@@ -506,6 +530,7 @@ fn run_tasks(
         image: toastfile.image.clone(),
         persist: true,
         interrupted: interrupted.clone(),
+        docker_cli: settings.docker_cli.clone(),
     });
 
     // Run each task in the schedule.
@@ -535,10 +560,10 @@ fn run_tasks(
         info!("Running task {}\u{2026}", task_name.code_str());
         let (result, new_context) = runner::run(
             settings,
-            &environment,
-            &interrupted,
-            &active_containers,
-            &toastfile,
+            environment,
+            interrupted,
+            active_containers,
+            toastfile,
             task_data,
             caching_enabled,
             context.unwrap(), // Safe due to [ref:context_needed_if_not_final_task].
@@ -575,12 +600,16 @@ fn entry() -> Result<(), Failure> {
     let interrupted = Arc::new(AtomicBool::new(false));
     let active_containers = Arc::new(Mutex::new(HashSet::<String>::new()));
 
-    // Set up the signal handlers.
-    set_up_signal_handlers(interrupted.clone(), active_containers.clone())?;
-
     // Parse the command-line arguments;
     let settings = settings()?;
 
+    // Set up the signal handlers.
+    set_up_signal_handlers(
+        settings.docker_cli.clone(),
+        interrupted.clone(),
+        active_containers.clone(),
+    )?;
+
     // Parse the toastfile.
     let toastfile = parse_toastfile(&settings.toastfile_path)?;
 
@@ -715,6 +744,7 @@ fn entry() -> Result<(), Failure> {
 
         // Spawn the shell.
         docker::spawn_shell(
+            &settings.docker_cli,
             &context.unwrap().image, // Safe due to [ref:spawn_shell_requires_context].
             &toastfile_dir,
             &task_environment,
